V9.4 Verify that all cached or temporary copies of sensitive data sent to the client are protected from unauthorized access or purged&#47;invalidated after the authorized user accesses the sensitive data (e.g., the proper no-cache and no-store Cache-Control headers are set).